Python: module requests_management

requests_management (version 0.1.0) | index requests_management.py

`This tools run scripts and display the result in a Web Interface.
This file implement some functions to manage requests/reports on WebScripts.`

Modules
`` |  |
csv | json | ntpath |

Classes
`` |  | builtins.tuple(builtins.object) Request
class Request(builtins.tuple)
`` | `Request(ID, Time, UserName, ErrorCode, Page, UserAgent, Subject, Reason, Name) Request(ID, Time, UserName, ErrorCode, Page, UserAgent, Subject, Reason, Name)`
| Method resolution order: Request builtins.tuple builtins.object Methods defined here: __getnewargs__(self) `Return self as a plain tuple. Used by copy and pickle.` __repr__(self) `Return a nicely formatted representation string` _asdict(self) `Return a new dict which maps field names to their values.` _replace(self, /, **kwds) `Return a new Request object replacing specified fields with new values` Class methods defined here: _make(iterable) from builtins.type `Make a new Request object from a sequence or iterable` Static methods defined here: __new__(_cls, ID, Time, UserName, ErrorCode, Page, UserAgent, Subject, Reason, Name) `Create new instance of Request(ID, Time, UserName, ErrorCode, Page, UserAgent, Subject, Reason, Name)` Data descriptors defined here: ID `Alias for field number 0` Time `Alias for field number 1` UserName `Alias for field number 2` ErrorCode `Alias for field number 3` Page `Alias for field number 4` UserAgent `Alias for field number 5` Subject `Alias for field number 6` Reason `Alias for field number 7` Name `Alias for field number 8` Data and other attributes defined here: _field_defaults = {} _fields = ('ID', 'Time', 'UserName', 'ErrorCode', 'Page', 'UserAgent', 'Subject', 'Reason', 'Name') Methods inherited from builtins.tuple: __add__(self, value, /) `Return self+value.` __contains__(self, key, /) `Return key in self.` __eq__(self, value, /) `Return self==value.` __ge__(self, value, /) `Return self>=value.` __getattribute__(self, name, /) `Return getattr(self, name).` __getitem__(self, key, /) `Return self[key].` __gt__(self, value, /) `Return self>value.` __hash__(self, /) `Return hash(self).` __iter__(self, /) `Implement iter(self).` __le__(self, value, /) `Return self<=value.` __len__(self, /) `Return len(self).` __lt__(self, value, /) `Return self<value.` __mul__(self, value, /) `Return self*value.` __ne__(self, value, /) `Return self!=value.` __rmul__(self, value, /) `Return value*self.` count(self, value, /) `Return number of occurrences of value.` index(self, value, start=0, stop=9223372036854775807, /) `Return first index of value. Raises ValueError if the value is not present.` Class methods inherited from builtins.tuple: __class_getitem__(...) from builtins.type `See PEP 585`

Functions
`` |  | delete_request(id_: str) -> requests_management.Request `This function rewrite the request database without the specified request.` get_request(id_: str) -> requests_management.Request `This function return a specific request.` get_requests() -> collections.abc.Iterator `This function build Uploads from database.`

Data
`` |  | __all__ = ['Request', 'get_requests', 'get_request', 'delete_request'] __author_email__ = 'mauricelambert434@gmail.com' __copyright__ = '\nWebScripts Copyright (C) 2021 Maurice Lambert...ome to redistribute it\nunder certain conditions.\n' __description__ = '\nThis tools run scripts and display the result i...unctions to manage requests/reports on WebScripts' __license__ = 'GPL-3.0 License' __maintainer__ = 'Maurice Lambert' __maintainer_email__ = 'mauricelambert434@gmail.com' __url__ = 'https://github.com/mauricelambert/WebScripts'

Author
`` |  | Maurice Lambert